/* $Id: screen.h,v 1.2 2006/01/13 20:57:48 cegger Exp $
***************************************************************************

   X server for LibGGI - Graphics acceleration for backingstore functions

   Copyright (C) 1997      Michael Krause       [rawstyle@ms.demo.org]
   Copyright (C) 1998-1999 Marcus Sundberg      [marcus@ggi-project.org]

   Permission is hereby granted, free of charge, to any person obtaining a
   copy of this software and associated documentation files (the "Software"),
   to deal in the Software without restriction, including without limitation
   the rights to use, copy, modify, merge, publish, distribute, sublicense,
   and/or sell copies of the Software, and to permit persons to whom the
   Software is furnished to do so, subject to the following conditions:

   The above copyright notice and this permission notice shall be included in
   all copies or substantial portions of the Software.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
   THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
   IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
   CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

***************************************************************************
*/

#ifndef _XGGI_ACCEL_SCREEN_H
#define _XGGI_ACCEL_SCREEN_H


#define PSZ 8
#include <ggi/gg.h>
   
#include "mi.h"
#include "cfb.h"
#include "cfb16.h"
#include "cfb24.h"
#include "cfb32.h"
   
#include "scrnintstr.h"
#include "gcstruct.h"
   
#include "xggi.h"


/*
 * xggiSaveRestoreAreas - accelerated replacement for cfbSaveAreas & cfbRestoreAreas
 *
 */
void xggiSaveRestoreAreas(PixmapPtr pPixmap,	/* Backing pixmap */
			RegionPtr prgnSave,	/* Region to save (pixmap/screen-relative) */
			int xorg,		/* X origin of region */
			int yorg,		/* Y origin of region */
			WindowPtr pWin);

/* implements pScreen->CloseScreen */
Bool xggiCloseScreen(int idx, ScreenPtr pScreen);

/*
 * xggiCopyWindow - accelerated replacement for cfbCopyWindow
 *
 * pWin->drawable.x/y contains the destination position
 * ptOldOrg contains the old position
 * prgnSrc is a region describing the part of the source to be moved
 *  (this is padded by one pixel at all four edges of a window?!?!?)
 *
 * I don't really understand this, BTW ;)
 *
 */
void
xggiCopyWindow(WindowPtr pWin, DDXPointRec ptOldOrg, RegionPtr prgnSrc);


/*
 * xggiGetImage - accelerated replacement for cfbGetImage
 *
 */
void xggiGetImage(DrawablePtr pDrawable,
			int sx, int sy, int w, int h,
			unsigned int format,
			unsigned long planeMask,
			char *pdstLine);

/*
 * xggiGetSpans - accelerated replacement for cfbGetSpans
 *
 */
void xggiGetSpans(
		DrawablePtr pDrawable,	/* drawable from which to get bits */
		int wMax,		/* largest value of all *pwidths */
		DDXPointPtr ppt,	/* points to start copying from */
		int *pwidth,		/* list of number of bits to copy */
		int nspans,		/* number of scanlines to copy */
		char *pchardstStart	/* where to put the bits */
		);

/*
 * xggiPaintWindow - accelerated replacement for cfbPaintWindow
 *
 */
void xggiPaintWindow(WindowPtr pWin, RegionPtr prgn, int what);


#endif	/* _XGGI_ACCEL_SCREEN_H */

